//---------------------------------------------------------------------------
//
// Evj        Model the evolution of DNA binding site recognition
//
// Module:    Nexus, a class that acts as a nexus between the simulator
//            and the GUI
// Author:    Paul C. Anagnostopoulos
// Created:   3 April 2005
//
// This computer program fits the description in the U.S. Copyright Act
// of a "United States Government work." It was written as a part of
// my/our official duties as a Government employee. This means it cannot
// be copyrighted. The program is freely available for use without a
// copyright notice, and there are no restrictions on its use, now or
// subsequently. We retain no rights in the program. Please acknowledge
// the source of this code in any releases you make.
//
//---------------------------------------------------------------------------


// The Nexus object contains information that is passed from the
// simulator to the GUI, in order to display the results of the
// simulation.

public final class Nexus
{
  // Simulation parameters.

  public String title;
  public int generation;
  public int cycles;
  public boolean pausePerfect;
  public boolean pauseConverged;
  public int population;
  public int potentialSites;
  public int sites;
  public int siteWidth;
  public int mutations;
  public boolean selection;
  public double Rfreq;
  public int bestID, worstID;
  public int bestAge, worstAge;
  public int bestMistakes, worstMistakes;
  public double bestRseq, worstRseq;
  public boolean perfection;
  public boolean convergence;
  public boolean perfecgence;

  // Some additional values of use.
  
  public int weightWidth;         // Width of weight in matrix.
  public boolean useFounder;      // True if using founder model.
  public int founders;            // Number of founders.
  public int genePos;             // Position of gene on chromosome.
  public int thresholdPos;        // Position of threshold on chromosome.
  public int availablePos;        // Position of binding site portion.
  public int sitePos[];           // Array of positions of binding sites.
  
  // Some statistics.

  public int births;              // Total births.
  public int deaths,              // Total deaths.
             selectionDeaths;     // Deaths by selection.
  public double E_Hnb;            // E(Hnb). See Stats class.
  
  // These values are needed by various displays. They pertain to the
  // best creature in this generation.

  public byte chromosome[];       // Chromosome.
  public int threshold;           // Threshold value.
  public int minValuation,        // Minimum and maximum possible valuation
             maxValuation;        // of a binding site.
  public PosInfo posInfo[];       // Position info (see PosInfo class).
  
  // Trivial constructor, since this is just a public record.
  
  public Nexus () { }
}
